@@ -237,8 +237,12 @@ class ScheduleHandler_smartsheet(ScheduleHandlerBase):
                 self.schedule.unique_id_re.sub('_', self.schedule.name))
             self.schedule.mtime = self.get_handle_mtime()
             self.schedule.changelog = self.get_handle_changelog()
-            self.schedule.dStart = datetime.datetime.max
-            self.schedule.dFinish = datetime.datetime.min
+            if self.options.get('trim_time'):
+                self.schedule.dStart = datetime.date.max
+                self.schedule.dFinish = datetime.date.min
+            else:
+                self.schedule.dStart = datetime.datetime.max
+                self.schedule.dFinish = datetime.datetime.min
             log.debug('Import schedule - after first call to smartsheet')
 
             parents_stack = []
@@ -298,6 +302,9 @@ class ScheduleHandler_smartsheet(ScheduleHandlerBase):
         if date:
             date = date.replace(second=0)
 
+        if date is not None and self.options.get('trim_time'):
+            date = date.date()
+
         return date
 
     def _load_task(self, row, parents_stack):
@@ -313,10 +320,7 @@ class ScheduleHandler_smartsheet(ScheduleHandlerBase):
             # skip load, task doesn't contain all needed info
             return
 
-        try:
-            task.name = unicode(cells[COLUMN_TASK_NAME])
-        except NameError:
-            task.name = str(cells[COLUMN_TASK_NAME])
+        task.name = str(cells[COLUMN_TASK_NAME])
 
         # dates
         task.dStart = self._parse_date(cells[COLUMN_START])
@@ -330,10 +334,7 @@ class ScheduleHandler_smartsheet(ScheduleHandlerBase):
         self.schedule.dFinish = max(self.schedule.dFinish, task.dFinish)
 
         if COLUMN_NOTE in cells and cells[COLUMN_NOTE]:
-            try:
-                task.note = unicode(cells[COLUMN_NOTE])
-            except NameError:
-                task.note = str(cells[COLUMN_NOTE])
+            task.note = str(cells[COLUMN_NOTE])
 
         if COLUMN_PRIORITY in cells:
             task.priority = cells[COLUMN_PRIORITY]
